@@ -14,6 +14,7 @@ from frontengine.utils.multi_language.language_wrapper import language_wrapper
 class VideoWidget(QVideoWidget):
 
     def __init__(self, video_path: str):
+        front_engine_logger.info(f"Init VideoWidget video_path: {video_path}")
         super().__init__()
         self.opacity: float = 0.2
         self.volume: float = 1
@@ -47,6 +48,7 @@ class VideoWidget(QVideoWidget):
 
 
     def set_ui_window_flag(self, show_on_bottom: bool = False) -> None:
+        front_engine_logger.info(f"VideoWidget set_ui_window_flag show_on_bottom: {show_on_bottom}")
         self.setWindowFlag(
             Qt.WindowType.WindowTransparentForInput |
             Qt.WindowType.FramelessWindowHint |
@@ -59,27 +61,36 @@ class VideoWidget(QVideoWidget):
             self.setWindowFlag(Qt.WindowType.WindowStaysOnBottomHint)
 
     def set_ui_variable(self, opacity: float = 0.2) -> None:
+        front_engine_logger.info(f"VideoWidget set_ui_variable opacity: {opacity}")
         self.opacity = opacity
         self.setWindowOpacity(self.opacity)
 
     def set_player_variable(self, play_rate: float = 1, volume: float = 1) -> None:
+        front_engine_logger.info("VideoWidget set_player_variable "
+                                 f"play_rate: {play_rate} "
+                                 f"volume: {volume}")
         self.play_rate = play_rate
         self.volume = volume
         self.media_player.setPlaybackRate(self.play_rate)
         self.media_player.audioOutput().setVolume(self.volume)
 
     def closeEvent(self, event) -> None:
+        front_engine_logger.info(f"VideoWidget closeEvent event: {event}")
         super().closeEvent(event)
         self.media_player.stop()
 
     def video_player_error(self) -> None:
+        front_engine_logger.info("VideoWidget video_player_error")
         print(self.media_player.error())
 
     def mousePressEvent(self, event) -> None:
+        front_engine_logger.info(f"VideoWidget mousePressEvent event: {event}")
         super().mousePressEvent(event)
 
     def mouseDoubleClickEvent(self, event) -> None:
+        front_engine_logger.info(f"VideoWidget mouseDoubleClickEvent event: {event}")
         super().mouseDoubleClickEvent(event)
 
     def mouseGrabber(self) -> None:
+        front_engine_logger.info("VideoWidget mouseGrabber")
         super().mouseGrabber()
