@@ -2,6 +2,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from frontengine.utils.browser.browser import open_browser
+from frontengine.utils.logging.loggin_instance import front_engine_logger
 
 if TYPE_CHECKING:
     from frontengine.ui.main_ui import FrontEngineMainUI
@@ -11,6 +12,7 @@ from frontengine.utils.multi_language.language_wrapper import language_wrapper
 
 
 def build_how_to_menu(ui_we_want_to_set: FrontEngineMainUI) -> None:
+    front_engine_logger.info(f"how_to_menu.py build_how_to_menu ui_we_want_to_set: {ui_we_want_to_set}")
     ui_we_want_to_set.how_to_menu = ui_we_want_to_set.menu_bar.addMenu(
         language_wrapper.language_word_dict.get("doc_menu_label")
     )
